# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`icinga::agent`](#icingaagent): Setup a Icinga agent.
* [`icinga::db`](#icingadb)
* [`icinga::db::database`](#icingadbdatabase): Setup database for IcingaDB.
* [`icinga::ido`](#icingaido): Configure IDO Backend.
* [`icinga::ido::database`](#icingaidodatabase): Configure IDO backend database.
* [`icinga::redis`](#icingaredis): Base class for all redis owned by Icinga.
* [`icinga::repos`](#icingarepos): This class manages the stages stable, testing and snapshot of packages.icinga.com repository and depending on the operating system platform s
* [`icinga::server`](#icingaserver): Setup a Icinga server.
* [`icinga::web`](#icingaweb): Setup Icinga Web 2 including a database backend for user settings,
PHP and a Webserver.
* [`icinga::web::database`](#icingawebdatabase): Setup Icinga Web 2 database for user settings.
* [`icinga::web::director`](#icingawebdirector): Setup Director module for Icinga Web 2
* [`icinga::web::director::database`](#icingawebdirectordatabase): Setup Director database.
* [`icinga::web::icingadb`](#icingawebicingadb): Setup IcingaDB module for the new backend.
* [`icinga::web::monitoring`](#icingawebmonitoring): Setup Monitoring module for the IDO backend.
* [`icinga::web::reporting`](#icingawebreporting): Setup the reporting module for Icinga Web 2
* [`icinga::web::reporting::database`](#icingawebreportingdatabase): Setup the reporting database.
* [`icinga::web::vspheredb`](#icingawebvspheredb): Setup VSphereDB module for Icinga Web 2
* [`icinga::web::vspheredb::database`](#icingawebvspheredbdatabase): Setup VSphereDB database.
* [`icinga::worker`](#icingaworker): Setup a Icinga worker (aka satellite).

#### Private Classes

* `icinga`: Configures the Icinga 2 Core and the api feature.
* `icinga::ca`: Configures the Icinga 2 CA and the api feature.
* `icinga::repos::apt`: Manage repositories via `apt`.
* `icinga::repos::yum`: Manage repositories via `yum`.
* `icinga::repos::zypper`: Manage repositories via `zypper`.

### Defined types

#### Public Defined types

* [`icinga::cert`](#icingacert): A class to generate tls key, cert and cacert files.

#### Private Defined types

* `icinga::database`: Private define resource for database backends.

### Functions

* [`icinga::cert::files`](#icingacertfiles): Choose the path of tls key, cert and ca file.
* [`icinga::db::connect`](#icingadbconnect): This function returns a string to connect databases
with or without TLS information.
* [`icinga::newline`](#icinganewline): Replace newlines for Windows systems.
* [`icinga::prepare_web`](#icingaprepare_web): This funktion checks for web preparation and display a warning if fails
* [`icinga::unwrap`](#icingaunwrap): This function returns an unwrap string if necessary.

### Data types

* [`Icinga::Certificate`](#icingacertificate): A strict type for a certificate
* [`Icinga::LogLevel`](#icingaloglevel): A strict type for log levels
* [`Icinga::Secret`](#icingasecret): A strict type for the secrets like passwords or keys

## Classes

### <a name="icingaagent"></a>`icinga::agent`

Setup a Icinga agent.

#### Parameters

The following parameters are available in the `icinga::agent` class:

* [`ca_server`](#ca_server)
* [`parent_zone`](#parent_zone)
* [`parent_endpoints`](#parent_endpoints)
* [`global_zones`](#global_zones)
* [`logging_type`](#logging_type)
* [`logging_level`](#logging_level)
* [`zone`](#zone)
* [`run_web`](#run_web)

##### <a name="ca_server"></a>`ca_server`

Data type: `Stdlib::Host`

The CA to send the certificate request to.

##### <a name="parent_zone"></a>`parent_zone`

Data type: `String`

Name of the parent Icinga zone.

Default value: `'main'`

##### <a name="parent_endpoints"></a>`parent_endpoints`

Data type: `Hash[String, Hash]`

Configures these endpoints of the parent zone.

##### <a name="global_zones"></a>`global_zones`

Data type: `Array[String]`

List of global zones to configure.

Default value: `[]`

##### <a name="logging_type"></a>`logging_type`

Data type: `Enum['file', 'syslog']`

Switch the log target. Only `file` is supported on Windows.

Default value: `'file'`

##### <a name="logging_level"></a>`logging_level`

Data type: `Optional[Icinga::LogLevel]`

Set the log level.

Default value: ``undef``

##### <a name="zone"></a>`zone`

Data type: `String`

Set a dedicated zone name.

Default value: `'NodeName'`

##### <a name="run_web"></a>`run_web`

Data type: `Boolean`

Prepare to run Icinga Web 2 on the same machine. Manage a group `icingaweb2`
and add the Icinga user to this group.

Default value: ``false``

### <a name="icingadb"></a>`icinga::db`

The icinga::db class.

#### Parameters

The following parameters are available in the `icinga::db` class:

* [`db_type`](#db_type)
* [`db_host`](#db_host)
* [`db_port`](#db_port)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`db_pass`](#db_pass)
* [`manage_database`](#manage_database)
* [`db_accesses`](#db_accesses)
* [`redis_host`](#redis_host)
* [`redis_bind`](#redis_bind)
* [`redis_port`](#redis_port)
* [`redis_pass`](#redis_pass)
* [`manage_redis`](#manage_redis)
* [`manage_feature`](#manage_feature)

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql', 'pgsql']`

Choose wether MySQL or PostgreSQL as backend for historical data.

##### <a name="db_host"></a>`db_host`

Data type: `Stdlib::Host`

Database server.

Default value: `'localhost'`

##### <a name="db_port"></a>`db_port`

Data type: `Optional[Stdlib::Port::Unprivileged]`

Port to connect the database.

Default value: ``undef``

##### <a name="db_name"></a>`db_name`

Data type: `String`

The IcingaDB database.

Default value: `'icingadb'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

User to connect the database.

Default value: `'icingadb'`

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Passwort to login into database.

##### <a name="manage_database"></a>`manage_database`

Data type: `Boolean`

Install and create database on localhost.

Default value: ``false``

##### <a name="db_accesses"></a>`db_accesses`

Data type: `Array[Stdlib::Host]`

List of hosts with access to the database, e.g. host running Icinga Web 2.
Omly valid if `manage_database` is `true`.

Default value: `[]`

##### <a name="redis_host"></a>`redis_host`

Data type: `Stdlib::Host`

Redis host to connect.

Default value: `'localhost'`

##### <a name="redis_bind"></a>`redis_bind`

Data type: `Optional[Array[Stdlib::Host]]`

When Redis runs on a differnt host than Icinga, here the listining interfaces
have to be set.

Default value: ``undef``

##### <a name="redis_port"></a>`redis_port`

Data type: `Optional[Stdlib::Port]`

Port for Redis listening.

Default value: ``undef``

##### <a name="redis_pass"></a>`redis_pass`

Data type: `Optional[Icinga::Secret]`

Password to authenticate against Redis.

Default value: ``undef``

##### <a name="manage_redis"></a>`manage_redis`

Data type: `Boolean`

Install and create the IcingaDB Redis service on localhost.

Default value: ``true``

##### <a name="manage_feature"></a>`manage_feature`

Data type: `Boolean`

If you wanna manage the Icinga 2 feature for the IcingaDB, set this to `true`.
This only make sense when an Icinga 2 Server is running on the same host.

Default value: ``true``

### <a name="icingadbdatabase"></a>`icinga::db::database`

Setup database for IcingaDB.

#### Parameters

The following parameters are available in the `icinga::db::database` class:

* [`db_type`](#db_type)
* [`access_instances`](#access_instances)
* [`db_pass`](#db_pass)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`tls`](#tls)

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql','pgsql']`

What kind of database type to use.

##### <a name="access_instances"></a>`access_instances`

Data type: `Array[Stdlib::Host]`

List of Hosts to allow write access to the database. Usually an IcingaDB instance.

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Password to connect the database.

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the database.

Default value: `'icingadb'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

Database user name.

Default value: `'icingadb'`

##### <a name="tls"></a>`tls`

Data type: `Variant[Boolean,
  Enum['password','cert']]`

Access only for TLS encrypted connections. Authentication via `password` or `cert`,
value `true` means password auth.

Default value: ``false``

### <a name="icingaido"></a>`icinga::ido`

Configure IDO Backend.

#### Parameters

The following parameters are available in the `icinga::ido` class:

* [`db_pass`](#db_pass)
* [`db_type`](#db_type)
* [`db_host`](#db_host)
* [`db_port`](#db_port)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`manage_database`](#manage_database)
* [`enable_ha`](#enable_ha)

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Password to connect the database.

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql','pgsql']`

What kind of database type to use.

Default value: `'mysql'`

##### <a name="db_host"></a>`db_host`

Data type: `Stdlib::Host`

Database host to connect.

Default value: `'localhost'`

##### <a name="db_port"></a>`db_port`

Data type: `Optional[Stdlib::Port]`

Port to connect. Only affects for connection to remote database hosts.

Default value: ``undef``

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the database.

Default value: `'icinga2'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

Database user name.

Default value: `'icinga2'`

##### <a name="manage_database"></a>`manage_database`

Data type: `Boolean`

Create database and import schema.

Default value: ``false``

##### <a name="enable_ha"></a>`enable_ha`

Data type: `Boolean`

Enable HA feature for database.

Default value: ``false``

### <a name="icingaidodatabase"></a>`icinga::ido::database`

Configure IDO backend database.

#### Parameters

The following parameters are available in the `icinga::ido::database` class:

* [`db_type`](#db_type)
* [`ido_instances`](#ido_instances)
* [`db_pass`](#db_pass)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`tls`](#tls)

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql','pgsql']`

What kind of database type to use.

##### <a name="ido_instances"></a>`ido_instances`

Data type: `Array[Stdlib::Host]`

List of Hosts to allow write access to the database.
Usually an Icinga Server with enabled IDO feature.

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Password to connect the database.

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the database.

Default value: `'icinga2'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

Database user name.

Default value: `'icinga2'`

##### <a name="tls"></a>`tls`

Data type: `Variant[Boolean,
  Enum['password','cert']]`

Access only for TLS encrypted connections. Authentication via `password` or `cert`,
value `true` means password auth.

Default value: ``false``

### <a name="icingaredis"></a>`icinga::redis`

Base class for all redis owned by Icinga.

### <a name="icingarepos"></a>`icinga::repos`

This class manages the stages stable, testing and snapshot of packages.icinga.com repository
and depending on the operating system platform some other repositories.

#### Examples

##### 

```puppet
require icinga::repos
```

#### Parameters

The following parameters are available in the `icinga::repos` class:

* [`manage_stable`](#manage_stable)
* [`manage_testing`](#manage_testing)
* [`manage_nightly`](#manage_nightly)
* [`configure_backports`](#configure_backports)
* [`manage_epel`](#manage_epel)
* [`manage_powertools`](#manage_powertools)
* [`manage_crb`](#manage_crb)
* [`manage_server_monitoring`](#manage_server_monitoring)
* [`manage_plugins`](#manage_plugins)
* [`manage_extras`](#manage_extras)

##### <a name="manage_stable"></a>`manage_stable`

Data type: `Boolean`

Manage the Icinga stable repository. Disabled by setting to 'false'. Defaults to 'true'.

##### <a name="manage_testing"></a>`manage_testing`

Data type: `Boolean`

Manage the Icinga testing repository to get access to release candidates.
Enabled by setting to 'true'. Defaults to 'false'.

##### <a name="manage_nightly"></a>`manage_nightly`

Data type: `Boolean`

Manage the Icinga snapshot repository to get access to nightly snapshots.
Enabled by setting to 'true'. Defaults to 'false'.

##### <a name="configure_backports"></a>`configure_backports`

Data type: `Boolean`

Enables or Disables the backports repository. Has only an effect on plattforms
simular to Debian. To configure the backports repo uses apt::backports in hiera.

##### <a name="manage_epel"></a>`manage_epel`

Data type: `Boolean`

Manage the EPEL (Extra Packages Enterprise Linux) repository that is needed for some package
like newer Boost libraries. Has only an effect on plattforms simular to RedHat Enterprise.

##### <a name="manage_powertools"></a>`manage_powertools`

Data type: `Boolean`

Manage the PowerTools repository that is needed for some package like nagios-plugins on
Linux Enterprise systems like Alma 8, Rocky 8 and CentOS Stream 8.

##### <a name="manage_crb"></a>`manage_crb`

Data type: `Boolean`

Manage the CRB repository that is needed for some package like nagios-plugins on
Linux Enterprise systems like Alma 9, Rocky 9 and CentOS Stream 9.

##### <a name="manage_server_monitoring"></a>`manage_server_monitoring`

Data type: `Boolean`

Manage the 'server:monitoring' repository on SLES platforms that is needed for some package
like monitoring-plugins-common. Additional also the 'monitoring-plugins' are provided by this
repository. Bye default the repository is added with a lower priority of 120.

##### <a name="manage_plugins"></a>`manage_plugins`

Data type: `Boolean`

Manage the NETWAYS plugins repository that provides some packages for additional plugins.

##### <a name="manage_extras"></a>`manage_extras`

Data type: `Boolean`

Manage the NETWAYS extras repository that provides some packages for extras.

### <a name="icingaserver"></a>`icinga::server`

Setup a Icinga server.

#### Parameters

The following parameters are available in the `icinga::server` class:

* [`ca`](#ca)
* [`config_server`](#config_server)
* [`zone`](#zone)
* [`colocation_endpoints`](#colocation_endpoints)
* [`workers`](#workers)
* [`global_zones`](#global_zones)
* [`ca_server`](#ca_server)
* [`ticket_salt`](#ticket_salt)
* [`web_api_user`](#web_api_user)
* [`web_api_pass`](#web_api_pass)
* [`director_api_user`](#director_api_user)
* [`director_api_pass`](#director_api_pass)
* [`logging_type`](#logging_type)
* [`logging_level`](#logging_level)
* [`run_web`](#run_web)

##### <a name="ca"></a>`ca`

Data type: `Boolean`

Enables a CA on this node.

Default value: ``false``

##### <a name="config_server"></a>`config_server`

Data type: `Boolean`

Enables that this node is the central configuration server.

Default value: ``false``

##### <a name="zone"></a>`zone`

Data type: `String`

Name of the Icinga zone.

Default value: `'main'`

##### <a name="colocation_endpoints"></a>`colocation_endpoints`

Data type: `Hash[String,Hash]`

When the zone includes more than one endpoint, set here the additional endpoint(s).
Icinga supports two endpoints per zone only.

Default value: `{}`

##### <a name="workers"></a>`workers`

Data type: `Hash[String,Hash]`

All worker zones with key 'endpoints' for
endpoint objects.

Default value: `{}`

##### <a name="global_zones"></a>`global_zones`

Data type: `Array[String]`

List of global zones to configure.

Default value: `[]`

##### <a name="ca_server"></a>`ca_server`

Data type: `Optional[Stdlib::Host]`

The CA to send the certificate request to.

Default value: ``undef``

##### <a name="ticket_salt"></a>`ticket_salt`

Data type: `Optional[Icinga::Secret]`

Set an alternate ticket salt to icinga::ticket_salt from Hiera.

Default value: ``undef``

##### <a name="web_api_user"></a>`web_api_user`

Data type: `String`

Icinga API user to connect Icinga 2. Notice: user is only created if a password is set.

Default value: `'icingaweb2'`

##### <a name="web_api_pass"></a>`web_api_pass`

Data type: `Optional[Icinga::Secret]`

Icinga API user password.

Default value: ``undef``

##### <a name="director_api_user"></a>`director_api_user`

Data type: `String`

Icinga API director user to connect Icinga 2. Notice: user is only created if a password is set.

Default value: `'director'`

##### <a name="director_api_pass"></a>`director_api_pass`

Data type: `Optional[Icinga::Secret]`

Icinga API director user password.

Default value: ``undef``

##### <a name="logging_type"></a>`logging_type`

Data type: `Enum['file', 'syslog']`

Switch the log target. Only `file` is supported on Windows.

Default value: `'file'`

##### <a name="logging_level"></a>`logging_level`

Data type: `Optional[Icinga::LogLevel]`

Set the log level.

Default value: ``undef``

##### <a name="run_web"></a>`run_web`

Data type: `Boolean`

Prepare to run Icinga Web 2 on the same machine. Manage a group `icingaweb2`
and add the Icinga user to this group.

Default value: ``false``

### <a name="icingaweb"></a>`icinga::web`

Setup Icinga Web 2 including a database backend for user settings,
PHP and a Webserver.

#### Parameters

The following parameters are available in the `icinga::web` class:

* [`default_admin_user`](#default_admin_user)
* [`default_admin_pass`](#default_admin_pass)
* [`db_pass`](#db_pass)
* [`apache_cgi_pass_auth`](#apache_cgi_pass_auth)
* [`db_type`](#db_type)
* [`db_host`](#db_host)
* [`db_port`](#db_port)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`manage_database`](#manage_database)
* [`api_host`](#api_host)
* [`api_user`](#api_user)
* [`api_pass`](#api_pass)

##### <a name="default_admin_user"></a>`default_admin_user`

Data type: `String`

Set the initial name of the admin user.

Default value: `'icingaadmin'`

##### <a name="default_admin_pass"></a>`default_admin_pass`

Data type: `Icinga::Secret`

Set the initial password for the admin user.

Default value: `'icingaadmin'`

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Password to connect the database.

##### <a name="apache_cgi_pass_auth"></a>`apache_cgi_pass_auth`

Data type: `Boolean`

Either turn on or off the apache cgi pass thru auth.
An option available since Apache v2.4.15 and required for authenticated access to the Icinga Web Api.

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql', 'pgsql']`

What kind of database type to use.

Default value: `'mysql'`

##### <a name="db_host"></a>`db_host`

Data type: `Stdlib::Host`

Database host to connect.

Default value: `'localhost'`

##### <a name="db_port"></a>`db_port`

Data type: `Optional[Stdlib::Port::Unprivileged]`

Port to connect. Only affects for connection to remote database hosts.

Default value: ``undef``

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the database.

Default value: `'icingaweb2'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

Database user name.

Default value: `'icingaweb2'`

##### <a name="manage_database"></a>`manage_database`

Data type: `Boolean`

Create database.

Default value: ``false``

##### <a name="api_host"></a>`api_host`

Data type: `Variant[Stdlib::Host, Array[Stdlib::Host]]`

Single or list of Icinga 2 API endpoints to connect.

Default value: `'localhost'`

##### <a name="api_user"></a>`api_user`

Data type: `String`

Icinga 2 API user.

Default value: `'icingaweb2'`

##### <a name="api_pass"></a>`api_pass`

Data type: `Icinga::Secret`

Password to connect the Icinga 2 API.

### <a name="icingawebdatabase"></a>`icinga::web::database`

Setup Icinga Web 2 database for user settings.

#### Parameters

The following parameters are available in the `icinga::web::database` class:

* [`db_type`](#db_type)
* [`web_instances`](#web_instances)
* [`db_pass`](#db_pass)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`tls`](#tls)

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql','pgsql']`

What kind of database type to use.

##### <a name="web_instances"></a>`web_instances`

Data type: `Array[Stdlib::Host]`

List of Hosts to allow write access to the database. Usually an Icinga Web 2 instance.

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Password to connect the database.

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the database.

Default value: `'icingaweb2'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

Database user name.

Default value: `'icingaweb2'`

##### <a name="tls"></a>`tls`

Data type: `Variant[Boolean,
  Enum['password','cert']]`

Access only for TLS encrypted connections. Authentication via `password` or `cert`,
value `true` means password auth.

Default value: ``false``

### <a name="icingawebdirector"></a>`icinga::web::director`

Setup Director module for Icinga Web 2

#### Parameters

The following parameters are available in the `icinga::web::director` class:

* [`service_ensure`](#service_ensure)
* [`service_enable`](#service_enable)
* [`db_type`](#db_type)
* [`db_host`](#db_host)
* [`db_port`](#db_port)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`db_pass`](#db_pass)
* [`endpoint`](#endpoint)
* [`manage_database`](#manage_database)
* [`api_host`](#api_host)
* [`api_user`](#api_user)
* [`api_pass`](#api_pass)

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

Manages if the Director service should be stopped or running.

Default value: `'running'`

##### <a name="service_enable"></a>`service_enable`

Data type: `Boolean`

If set to true the Director service will start on boot.

Default value: ``true``

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql', 'pgsql']`

Type of your database. Either `mysql` or `pgsql`.

Default value: `'mysql'`

##### <a name="db_host"></a>`db_host`

Data type: `Stdlib::Host`

Hostname of the database.

Default value: `'localhost'`

##### <a name="db_port"></a>`db_port`

Data type: `Optional[Stdlib::Port]`

Port of the database.

Default value: ``undef``

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the database.

Default value: `'director'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

Username for DB connection.

Default value: `'director'`

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Password for DB connection.

##### <a name="endpoint"></a>`endpoint`

Data type: `String`

Endpoint object name of Icinga 2 API.

##### <a name="manage_database"></a>`manage_database`

Data type: `Boolean`

Create database and import schema.

Default value: ``false``

##### <a name="api_host"></a>`api_host`

Data type: `Stdlib::Host`

Icinga 2 API hostname.

Default value: `'localhost'`

##### <a name="api_user"></a>`api_user`

Data type: `String`

Icinga 2 API username.

Default value: `'director'`

##### <a name="api_pass"></a>`api_pass`

Data type: `Icinga::Secret`

Icinga 2 API password.

### <a name="icingawebdirectordatabase"></a>`icinga::web::director::database`

Setup Director database.

#### Parameters

The following parameters are available in the `icinga::web::director::database` class:

* [`db_type`](#db_type)
* [`web_instances`](#web_instances)
* [`db_pass`](#db_pass)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`tls`](#tls)

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql','pgsql']`

What kind of database type to use.

##### <a name="web_instances"></a>`web_instances`

Data type: `Array[Stdlib::Host]`

List of Hosts to allow write access to the database.
Usually an Icinga Web 2 instance.

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Password to connect the database.

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the database.

Default value: `'director'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

Database user name.

Default value: `'director'`

##### <a name="tls"></a>`tls`

Data type: `Variant[Boolean,
  Enum['password','cert']]`

Access only for TLS encrypted connections. Authentication via `password` or `cert`,
value `true` means password auth.

Default value: ``false``

### <a name="icingawebicingadb"></a>`icinga::web::icingadb`

Setup IcingaDB module for the new backend.

#### Parameters

The following parameters are available in the `icinga::web::icingadb` class:

* [`db_type`](#db_type)
* [`db_host`](#db_host)
* [`db_port`](#db_port)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`db_pass`](#db_pass)
* [`redis_host`](#redis_host)
* [`redis_port`](#redis_port)
* [`redis_pass`](#redis_pass)
* [`redis_primary_host`](#redis_primary_host)
* [`redis_primary_port`](#redis_primary_port)
* [`redis_primary_pass`](#redis_primary_pass)
* [`redis_secondary_host`](#redis_secondary_host)
* [`redis_secondary_port`](#redis_secondary_port)
* [`redis_secondary_pass`](#redis_secondary_pass)

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql', 'pgsql']`

What kind of database type to use as backend.

##### <a name="db_host"></a>`db_host`

Data type: `Stdlib::Host`

Database host to connect for the backenend.

Default value: `'localhost'`

##### <a name="db_port"></a>`db_port`

Data type: `Optional[Stdlib::Port::Unprivileged]`

Port to connect the backend.

Default value: ``undef``

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the database backend.

Default value: `'icingadb'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

Database backend user name.

Default value: `'icingadb'`

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Password to connect the backend.

##### <a name="redis_host"></a>`redis_host`

Data type: `Stdlib::Host`

Redis host to connect.

Default value: `'localhost'`

##### <a name="redis_port"></a>`redis_port`

Data type: `Optional[Stdlib::Port]`

Connect `redis_host` om this port.

Default value: ``undef``

##### <a name="redis_pass"></a>`redis_pass`

Data type: `Optional[Icinga::Secret]`

Password for Redis connection.

Default value: ``undef``

##### <a name="redis_primary_host"></a>`redis_primary_host`

Data type: `Stdlib::Host`

Alternative parameter to use for `redis_host`. Useful for high availability environments.

Default value: `$redis_host`

##### <a name="redis_primary_port"></a>`redis_primary_port`

Data type: `Optional[Stdlib::Port]`

Alternative parameter to use for `redis_port`. Useful for high availability environments.

Default value: `$redis_port`

##### <a name="redis_primary_pass"></a>`redis_primary_pass`

Data type: `Optional[Icinga::Secret]`

Alternative parameter to use for `redis_passwod`. Useful for high availability environments.

Default value: `$redis_pass`

##### <a name="redis_secondary_host"></a>`redis_secondary_host`

Data type: `Optional[Stdlib::Host]`

Fallback Redis host to connect if the first one fails.

Default value: ``undef``

##### <a name="redis_secondary_port"></a>`redis_secondary_port`

Data type: `Optional[Stdlib::Port]`

Port to connect on the fallback Redis server.

Default value: ``undef``

##### <a name="redis_secondary_pass"></a>`redis_secondary_pass`

Data type: `Optional[Icinga::Secret]`

Password for the second Redis server.

Default value: ``undef``

### <a name="icingawebmonitoring"></a>`icinga::web::monitoring`

Setup Monitoring module for the IDO backend.

#### Parameters

The following parameters are available in the `icinga::web::monitoring` class:

* [`db_type`](#db_type)
* [`db_host`](#db_host)
* [`db_port`](#db_port)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`db_pass`](#db_pass)

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql', 'pgsql']`

What kind of database type to use as IDO backend.

Default value: `'mysql'`

##### <a name="db_host"></a>`db_host`

Data type: `Stdlib::Host`

Database host to connect for the IDO backenend.

Default value: `'localhost'`

##### <a name="db_port"></a>`db_port`

Data type: `Optional[Stdlib::Port::Unprivileged]`

Port to connect the IDO backend.

Default value: ``undef``

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the IDO database backend.

Default value: `'icinga2'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

IDO database backend user name.

Default value: `'icinga2'`

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Pasword to connect the IDO backend.

### <a name="icingawebreporting"></a>`icinga::web::reporting`

Setup the reporting module for Icinga Web 2

#### Parameters

The following parameters are available in the `icinga::web::reporting` class:

* [`service_ensure`](#service_ensure)
* [`service_enable`](#service_enable)
* [`db_type`](#db_type)
* [`db_host`](#db_host)
* [`db_port`](#db_port)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`db_pass`](#db_pass)
* [`manage_database`](#manage_database)
* [`mail`](#mail)

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

Manages if the reporting service should be stopped or running.

Default value: `'running'`

##### <a name="service_enable"></a>`service_enable`

Data type: `Boolean`

If set to true the reporting service will start on boot.

Default value: ``true``

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql', 'pgsql']`

Type of your database.

##### <a name="db_host"></a>`db_host`

Data type: `Stdlib::Host`

Hostname of the database.

Default value: `'localhost'`

##### <a name="db_port"></a>`db_port`

Data type: `Optional[Stdlib::Port]`

Port of the database.

Default value: ``undef``

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the database.

Default value: `'reporting'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

Username for DB connection.

Default value: `'reporting'`

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Password for DB connection.

##### <a name="manage_database"></a>`manage_database`

Data type: `Boolean`

Create database and import schema.

Default value: ``false``

##### <a name="mail"></a>`mail`

Data type: `Optional[String]`

Mails are sent with this sender address.

Default value: ``undef``

### <a name="icingawebreportingdatabase"></a>`icinga::web::reporting::database`

Setup the reporting database.

#### Parameters

The following parameters are available in the `icinga::web::reporting::database` class:

* [`db_type`](#db_type)
* [`web_instances`](#web_instances)
* [`db_pass`](#db_pass)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`tls`](#tls)

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql','pgsql']`

What kind of database type to use.

##### <a name="web_instances"></a>`web_instances`

Data type: `Array[Stdlib::Host]`

List of Hosts to allow write access to the database.
Usually an Icinga Web 2 instance.

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Password to connect the database.

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the database.

Default value: `'reporting'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

Database user name.

Default value: `'reporting'`

##### <a name="tls"></a>`tls`

Data type: `Variant[Boolean,
  Enum['password','cert']]`

Access only for TLS encrypted connections. Authentication via `password` or `cert`,
value `true` means password auth.

Default value: ``false``

### <a name="icingawebvspheredb"></a>`icinga::web::vspheredb`

Setup VSphereDB module for Icinga Web 2

#### Parameters

The following parameters are available in the `icinga::web::vspheredb` class:

* [`service_ensure`](#service_ensure)
* [`service_enable`](#service_enable)
* [`db_type`](#db_type)
* [`db_host`](#db_host)
* [`db_port`](#db_port)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`db_pass`](#db_pass)
* [`manage_database`](#manage_database)

##### <a name="service_ensure"></a>`service_ensure`

Data type: `Stdlib::Ensure::Service`

Manages if the VSphereDB service should be stopped or running.

Default value: `'running'`

##### <a name="service_enable"></a>`service_enable`

Data type: `Boolean`

If set to true the VSphereDB service will start on boot.

Default value: ``true``

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql']`

Type of your database. At the moment only `mysql` is supported by the Icinga team.

Default value: `'mysql'`

##### <a name="db_host"></a>`db_host`

Data type: `Stdlib::Host`

Hostname of the database.

Default value: `'localhost'`

##### <a name="db_port"></a>`db_port`

Data type: `Optional[Stdlib::Port]`

Port of the database.

Default value: ``undef``

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the database.

Default value: `'vspheredb'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

Username for DB connection.

Default value: `'vspheredb'`

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Password for DB connection.

##### <a name="manage_database"></a>`manage_database`

Data type: `Boolean`

Create database and import schema.

Default value: ``false``

### <a name="icingawebvspheredbdatabase"></a>`icinga::web::vspheredb::database`

Setup VSphereDB database.

#### Parameters

The following parameters are available in the `icinga::web::vspheredb::database` class:

* [`db_type`](#db_type)
* [`web_instances`](#web_instances)
* [`db_pass`](#db_pass)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`tls`](#tls)

##### <a name="db_type"></a>`db_type`

Data type: `Enum['mysql']`

What kind of database type to use.

##### <a name="web_instances"></a>`web_instances`

Data type: `Array[Stdlib::Host]`

List of Hosts to allow write access to the database. Usually an Icinga Web 2 instance.

##### <a name="db_pass"></a>`db_pass`

Data type: `Icinga::Secret`

Password to connect the database.

##### <a name="db_name"></a>`db_name`

Data type: `String`

Name of the database.

Default value: `'vspheredb'`

##### <a name="db_user"></a>`db_user`

Data type: `String`

Database user name.

Default value: `'vspheredb'`

##### <a name="tls"></a>`tls`

Data type: `Variant[Boolean,
  Enum['password','cert']]`

Access only for TLS encrypted connections. Authentication via `password` or `cert`,
value `true` means password auth.

Default value: ``false``

### <a name="icingaworker"></a>`icinga::worker`

Setup a Icinga worker (aka satellite).

#### Parameters

The following parameters are available in the `icinga::worker` class:

* [`ca_server`](#ca_server)
* [`zone`](#zone)
* [`parent_zone`](#parent_zone)
* [`parent_endpoints`](#parent_endpoints)
* [`colocation_endpoints`](#colocation_endpoints)
* [`global_zones`](#global_zones)
* [`logging_type`](#logging_type)
* [`logging_level`](#logging_level)
* [`run_web`](#run_web)

##### <a name="ca_server"></a>`ca_server`

Data type: `Stdlib::Host`

The CA to send the certificate request to.

##### <a name="zone"></a>`zone`

Data type: `String`

Name of the Icinga zone.

##### <a name="parent_zone"></a>`parent_zone`

Data type: `String`

Name of the parent Icinga zone.

Default value: `'main'`

##### <a name="parent_endpoints"></a>`parent_endpoints`

Data type: `Hash[String, Hash]`

Configures these endpoints of the parent zone.

##### <a name="colocation_endpoints"></a>`colocation_endpoints`

Data type: `Hash[String, Hash]`

When the zone includes more than one endpoint, set here the additional endpoint(s).
Icinga supports two endpoints per zone only.

Default value: `{}`

##### <a name="global_zones"></a>`global_zones`

Data type: `Array[String]`

List of global zones to configure.

Default value: `[]`

##### <a name="logging_type"></a>`logging_type`

Data type: `Enum['file', 'syslog']`

Switch the log target. Only `file` is supported on Windows.

Default value: `'file'`

##### <a name="logging_level"></a>`logging_level`

Data type: `Optional[Icinga::LogLevel]`

Set the log level.

Default value: ``undef``

##### <a name="run_web"></a>`run_web`

Data type: `Boolean`

Prepare to run Icinga Web 2 on the same machine. Manage a group `icingaweb2`
and add the Icinga user to this group.

Default value: ``false``

## Defined types

### <a name="icingacert"></a>`icinga::cert`

A class to generate tls key, cert and cacert files.

#### Parameters

The following parameters are available in the `icinga::cert` defined type:

* [`args`](#args)
* [`owner`](#owner)
* [`group`](#group)

##### <a name="args"></a>`args`

Data type: `Icinga::Certificate`

A config hash with the keys:
key_file, cert_file, cacert_file, key, cert and cacert

##### <a name="owner"></a>`owner`

Data type: `String`

Owner of the files.

##### <a name="group"></a>`group`

Data type: `String`

Group membership of all files.

## Functions

### <a name="icingacertfiles"></a>`icinga::cert::files`

Type: Puppet Language

Choose the path of tls key, cert and ca file.

#### `icinga::cert::files(String $name, Optional[Stdlib::Absolutepath] $default_dir, Optional[Stdlib::Absolutepath] $key_file = undef, Optional[Stdlib::Absolutepath] $cert_file = undef, Optional[Stdlib::Absolutepath] $cacert_file = undef, Optional[Variant[String, Sensitive]] $key = undef, Optional[String] $cert = undef, Optional[String] $cacert = undef)`

The icinga::cert::files function.

Returns: `Hash` Returned hash includes all paths and the key, cert and cacert.

##### `name`

Data type: `String`



##### `default_dir`

Data type: `Optional[Stdlib::Absolutepath]`



##### `key_file`

Data type: `Optional[Stdlib::Absolutepath]`



##### `cert_file`

Data type: `Optional[Stdlib::Absolutepath]`



##### `cacert_file`

Data type: `Optional[Stdlib::Absolutepath]`



##### `key`

Data type: `Optional[Variant[String, Sensitive]]`



##### `cert`

Data type: `Optional[String]`



##### `cacert`

Data type: `Optional[String]`



### <a name="icingadbconnect"></a>`icinga::db::connect`

Type: Puppet Language

This function returns a string to connect databases
with or without TLS information.

#### `icinga::db::connect(Struct[{
      type     => Enum['pgsql','mysql','mariadb'],
      host     => Stdlib::Host,
      port     => Optional[Stdlib::Port],
      database => String,
      username => String,
      password => Optional[Variant[String, Sensitive[String]]],
  }] $db, Hash[String, Any] $tls, Optional[Boolean] $use_tls = undef)`

The icinga::db::connect function.

Returns: `String` Connection string to connect database.

##### `db`

Data type: `Struct[{
      type     => Enum['pgsql','mysql','mariadb'],
      host     => Stdlib::Host,
      port     => Optional[Stdlib::Port],
      database => String,
      username => String,
      password => Optional[Variant[String, Sensitive[String]]],
  }]`



##### `tls`

Data type: `Hash[String, Any]`



##### `use_tls`

Data type: `Optional[Boolean]`



### <a name="icinganewline"></a>`icinga::newline`

Type: Puppet Language

Replace newlines for Windows systems.

#### `icinga::newline(Optional[String] $text)`

The icinga::newline function.

Returns: `String` Text with correct newlines.

##### `text`

Data type: `Optional[String]`



### <a name="icingaprepare_web"></a>`icinga::prepare_web`

Type: Puppet Language

This funktion checks for web preparation and display a warning if fails

#### `icinga::prepare_web(String $icingamod)`

The icinga::prepare_web function.

Returns: `Any` Nothing, statement function.

##### `icingamod`

Data type: `String`



### <a name="icingaunwrap"></a>`icinga::unwrap`

Type: Puppet Language

This function returns an unwrap string if necessary.

#### `icinga::unwrap(Optional[Variant[String, Sensitive[String]]] $arg = undef)`

The icinga::unwrap function.

Returns: `Any` The unwraped string.

##### `arg`

Data type: `Optional[Variant[String, Sensitive[String]]]`



## Data types

### <a name="icingacertificate"></a>`Icinga::Certificate`

A strict type for a certificate

Alias of

```puppet
Struct[{
    cert        => Optional[String],
    key         => Optional[Variant[String, Sensitive[String]]],
    cacert      => Optional[String],
    insecure    => Optional[Boolean],
    cert_file   => Optional[Stdlib::Absolutepath],
    key_file    => Optional[Stdlib::Absolutepath],
    cacert_file => Optional[Stdlib::Absolutepath],
}]
```

### <a name="icingaloglevel"></a>`Icinga::LogLevel`

A strict type for log levels

Alias of

```puppet
Enum['debug', 'information', 'notice', 'warning', 'critical']
```

### <a name="icingasecret"></a>`Icinga::Secret`

A strict type for the secrets like passwords or keys

Alias of

```puppet
Variant[String, Sensitive[String]]
```

